# frozen_string_literal: true

class QueueBackfillDeployTokensShardingKey < Gitlab::Database::Migration[2.2]
  milestone '17.3'
  restrict_gitlab_migration gitlab_schema: :gitlab_main

  MIGRATION = "BackfillDeployTokensShardingKey"
  DELAY_INTERVAL = 2.minutes
  BATCH_SIZE = 1000
  SUB_BATCH_SIZE = 100

  def up
    # Replaced by RequeueBackfillDeployTokensShardingKey
  end

  def down
    # Replaced by RequeueBackfillDeployTokensShardingKey
  end
end
